@@ -4,14 +4,24 @@ import sys
 from datetime import datetime
 from pathlib import Path
 
-LOG_PATH = Path(os.getcwd()).parent
+from poe.utility import load_config
+
+WORKING_DIR = Path(os.getcwd()).parent
+config = load_config(WORKING_DIR)
+try:
+    if config is not None:
+        WORKING_DIR = Path(config['LOGGER']['logs_absolute_path'])
+except KeyError as e:
+    print(f'"logs_absolute_path" is not set in [poe.ini]. LOGS location will be the same as working dir."')
+    print(f'WORKING_DIR: {WORKING_DIR}')
 
 
 class TestLogger(logging.Logger):
-    def __init__(self, *, folder='new', log_name='log', stdout=False):
+    def __init__(self, *, folder='LOGS', log_name='log', level='INFO', stdout='False'):
         super().__init__("logger")
-        if stdout:
-            self.addHandler(_StdOutHHandler())
+        self.level = getattr(logging, level)
+        if eval(stdout):
+            self.addHandler(_StdOutHHandler(level))
         self.addHandler(TxtFileHandler(folder=folder, log_name=log_name))
         self.handled_element_exceptions: list[dict[
                                               str:str,
@@ -21,18 +31,18 @@ class TestLogger(logging.Logger):
 
 
 class _StdOutHHandler(logging.StreamHandler):
-    def __init__(self):
+    def __init__(self, level):
         self.stream = sys.stdout
-        self.level = logging.DEBUG
+        self.level = getattr(logging, level)
         super().__init__(self.stream)
         self.setFormatter(StdOutFormatter())
 
 
 class TxtFileHandler(logging.FileHandler):
-    def __init__(self, *, folder='new', log_name):
+    def __init__(self, *, folder, log_name):
         self.filename = f'{log_name}_{datetime.now().strftime("%d-%m-%y__%H-%M-%S")}.log'
-        (LOG_PATH / folder).mkdir(exist_ok=True, parents=True)
-        super().__init__(str(LOG_PATH / folder / self.filename))
+        (WORKING_DIR / folder).mkdir(exist_ok=True, parents=True)
+        super().__init__(str(WORKING_DIR / folder / self.filename))
         self.setFormatter(TxtFileFormatter())
 
 
@@ -68,10 +78,15 @@ class StdOutFormatter(logging.Formatter):
         return formatter.format(record)
 
 
-logger = TestLogger(folder='LOGS', stdout=True)
+logger = TestLogger(stdout='False')
+if config:
+    LOG_NAME = config['LOGGER']['log_name']
+    LEVEL = config['LOGGER']['level']
+    STDOUT = config['LOGGER']['stdout']
+    logger = TestLogger(log_name=LOG_NAME, level=LEVEL, stdout=STDOUT)
 
 if __name__ == '__main__':
-    logger = TestLogger(folder='test-logger', stdout=True)
+    logger = TestLogger(folder='test-logger', stdout='True')
     logger.info('test')
     logger.debug('test')
     logger.warning('test')
