@@ -1,4 +1,24 @@
+import configparser
 import inspect
+from pathlib import Path
+
+
+def locate_file(dir_path, file):
+    file_path = None
+    for path in Path(dir_path).rglob(file):
+        file_path = path
+    if not file_path:
+        print(f"File [{file}] doesn't exist inside [{dir_path}] directory structure. Logger defaults will be used.")
+    return file_path
+
+
+def load_config(directory):
+    file_path = locate_file(directory, 'poe.ini')
+    if file_path:
+        config = configparser.ConfigParser()
+        config.read(file_path)
+        return config
+    return None
 
 
 def get_all_methods_and_properties(clazz):
@@ -15,8 +35,8 @@ def get_methods_and_properties(clazz, dont=False, starts_with=''):
 
 
 if __name__ == '__main__':
-    from poe import *
-    from aspect import TestLogger
+    from poe.logger import TestLogger
+    from poe.elements import ScreenElement, SelectElement, LabelElement, SectionElement, InputElement
 
     logger = TestLogger(folder='utility', stdout=True)
     logger.info(get_methods_and_properties(ScreenElement))
